clear;
close all;
clc;

M_s = 250; % Kg
k_s = 5000;% N/m
a_s = 1000;% N*s/m

A = [ 0 , 1 ; -k_s / M_s , -a_s / M_s ];	

autoval = eig( A )

%% tempo di risposta
lambdaD=max(real(autoval));   % parte reale dellautovalore dominante
TD=-1/lambdaD;                % costante di tempo dominante
TR=5*TD                       % tempo di risosta

%% salita del passeggero
m=80; g=9.81;
b=[0 -m*g/(4*M_s)]';
c=[1 0];
d=0;
sistema=ss(A,b,c,d);
T=linspace(0,2*TR,100);
U=ones(size(T));
sedile=lsim(sistema,U,T);
figure; plot(T,sedile);
xlabel('tempo [s]'); ylabel('posizione del sedile [m]');
title('salita del passeggero');

Xeq=-inv(A)*b*1
Yeq=c*Xeq+d*1

%% simulazione della rampa
B = [ 0 , 0 ; k_s / M_s , a_s / M_s ];
d = [ 0 0 ];
sistema2 = ss( A , B , c , d );

%% posizione media velocit
vel = 5 / 3.6;	% m/s
[xstrada,xdotstrada,tstrada]=genera_rampa(vel);
sedile2=lsim(sistema2,[xstrada;xdotstrada],tstrada);

figure;
plot(tstrada,sedile2);
grid on
xlabel('tempo [s]'); ylabel('posizione del sedile [m]');
hold on
plot(tstrada,xstrada,'r');
legend('posizione sedile','posizione rampa');
title(sprintf('velocit = %i km/h',vel*3.6))
axis([0 15 0 0.2])

%% posizione alta velocit
vel = 50 / 3.6;	% m/s
[xstrada,xdotstrada,tstrada]=genera_rampa(vel);
sedile2=lsim(sistema2,[xstrada;xdotstrada],tstrada);

figure;
plot(tstrada,sedile2);
grid on
xlabel('tempo [s]'); ylabel('posizione del sedile [m]');
hold on
plot(tstrada,xstrada,'r');
legend('posizione sedile','posizione rampa');
title(sprintf('velocit = %i km/h',vel*3.6))
axis([0 15 0 0.2])

%% posizione bassa velocit
vel = 1 / 3.6;	% m/s
[xstrada,xdotstrada,tstrada]=genera_rampa(vel);
sedile2=lsim(sistema2,[xstrada;xdotstrada],tstrada);

figure;
plot(tstrada,sedile2);
grid on
xlabel('tempo [s]'); ylabel('posizione del sedile [m]');
hold on
plot(tstrada,xstrada,'r');
legend('posizione sedile','posizione rampa');
title(sprintf('velocit = %i km/h',vel*3.6))
axis([0 15 0 0.2])

%% accelerazione media velocit
vel=5/3.6;					% m/s 

% y=x1 posizione del sedile
[xstrada,xdotstrada,tstrada]=genera_rampa(vel);
sedile2=lsim(sistema2,[xstrada;xdotstrada],tstrada);
sedile2=sedile2';

% y=x2 velocit del sedile
c=[0 1];
sistema2vel=ss(A,B,c,d);
velocita2= lsim(sistema2vel,[xstrada;xdotstrada],tstrada);
velocita2=velocita2';

% accelerazione
accel2=(-a_s*velocita2-k_s*sedile2+k_s*xstrada+a_s*xdotstrada)/M_s;

figure; plot(tstrada,accel2);
grid on;
xlabel('tempo [s]');
ylabel('accelerazione del sedile [m]');
title(sprintf( 'velocit = %i km/h',vel*3.6))

%% accelerazione alta velocit
vel=50/3.6;					% m/s 

% y=x1 posizione del sedile
[xstrada,xdotstrada,tstrada]=genera_rampa(vel);
sedile2=lsim(sistema2,[xstrada;xdotstrada],tstrada);
sedile2=sedile2';

% y=x2 velocit del sedile
c=[0 1];
sistema2vel=ss(A,B,c,d);
velocita2= lsim(sistema2vel,[xstrada;xdotstrada],tstrada);
velocita2=velocita2';

% accelerazione
accel2=(-a_s*velocita2-k_s*sedile2+k_s*xstrada+a_s*xdotstrada)/M_s;

figure; plot(tstrada,accel2);
grid on;
xlabel('tempo [s]');
ylabel('accelerazione del sedile [m]');
title(sprintf( 'velocit = %i km/h',vel*3.6))

%% accelerazione bassa velocit
vel=1/3.6;					% m/s 

% y=x1 posizione del sedile
[xstrada,xdotstrada,tstrada]=genera_rampa(vel);
sedile2=lsim(sistema2,[xstrada;xdotstrada],tstrada);
sedile2=sedile2';

% y=x2 velocit del sedile
c=[0 1];
sistema2vel=ss(A,B,c,d);
velocita2= lsim(sistema2vel,[xstrada;xdotstrada],tstrada);
velocita2=velocita2';

% accelerazione
accel2=(-a_s*velocita2-k_s*sedile2+k_s*xstrada+a_s*xdotstrada)/M_s;

figure; plot(tstrada,accel2);
grid on;
xlabel('tempo [s]');
ylabel('accelerazione del sedile [m]');
title(sprintf( 'velocit = %i km/h',vel*3.6))